@@ -13,7 +13,6 @@
 #define QT_FEATURE_imageformat_xpm 1
 #define QT_FEATURE_draganddrop 1
 #define QT_FEATURE_opengl 1
-#define QT_NO_EGL 
 #define QT_FEATURE_imageformatplugin 1
 #define QT_FEATURE_highdpiscaling 1
 #define QT_FEATURE_im 1
@@ -35,9 +34,12 @@
 #define QT_FEATURE_sessionmanager 1
 #define QT_FEATURE_shortcut 1
 #define QT_FEATURE_standarditemmodel 1
+#define QT_FEATURE_system_textmarkdownreader -1
 #define QT_FEATURE_systemtrayicon 1
 #define QT_FEATURE_tabletevent 1
 #define QT_FEATURE_texthtmlparser 1
+#define QT_FEATURE_textmarkdownreader 1
+#define QT_FEATURE_textmarkdownwriter 1
 #define QT_FEATURE_textodfwriter 1
 #define QT_FEATURE_validator 1
 #define QT_FEATURE_vulkan -1
